# <span class="badge package-core"></span> team

## Objects

 * <span class="badge object-type-class"></span> [Team](./object-Team.md)
## Builders

 * <span class="badge builder"></span> [Team](./builder-Team.md)
